Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SchedulableEntityRepoInterface ¶
type SchedulableEntityRepoInterface interface {
// Create a schedulable entity in the database store
Create(ctx context.Context, input models.SchedulableEntity) error
// Activate a schedulable entity in the database store.
Activate(ctx context.Context, input models.SchedulableEntity) error
// Deactivate a schedulable entity in the database store.
Deactivate(ctx context.Context, ID models.SchedulableEntityKey) error
// Get a schedulable entity from the database store using the schedulable entity id.
Get(ctx context.Context, ID models.SchedulableEntityKey) (models.SchedulableEntity, error)
// GetAll Gets all the active schedulable entities from the db
GetAll(ctx context.Context) ([]models.SchedulableEntity, error)
}
SchedulableEntityRepoInterface : An Interface for interacting with the schedulable entity in the database
type ScheduleEntitiesSnapShotRepoInterface ¶
type ScheduleEntitiesSnapShotRepoInterface interface {
// Create/ Update the snapshot in the database store
Write(ctx context.Context, input models.ScheduleEntitiesSnapshot) error
// Get the latest snapshot from the database store.
Read(ctx context.Context) (models.ScheduleEntitiesSnapshot, error)
}
ScheduleEntitiesSnapShotRepoInterface : An Interface for interacting with the snapshot of schedulable entities in the database
type SchedulerRepoInterface ¶ added in v0.6.100
type SchedulerRepoInterface interface {
SchedulableEntityRepo() SchedulableEntityRepoInterface
ScheduleEntitiesSnapshotRepo() ScheduleEntitiesSnapShotRepoInterface
}
Click to show internal directories.
Click to hide internal directories.