Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SchedulableEntity ¶
type SchedulableEntity struct {
models.BaseModel
SchedulableEntityKey
CronExpression string
FixedRateValue uint32
Unit admin.FixedRateUnit
KickoffTimeInputArg string
Active *bool
}
Database model to encapsulate metadata associated with a SchedulableEntity
type SchedulableEntityKey ¶
type SchedulableEntityKey struct {
Project string `gorm:"primary_key"`
Domain string `gorm:"primary_key"`
Name string `gorm:"primary_key"`
Version string `gorm:"primary_key"`
}
Schedulable entity primary key
type ScheduleEntitiesSnapshot ¶
type ScheduleEntitiesSnapshot struct {
models.BaseModel
Snapshot []byte `gorm:"column:snapshot" schema:"-"`
}
Database model to save the snapshot for the schedulable entities in the db
type ScheduleEntitiesSnapshotCollectionOutput ¶
type ScheduleEntitiesSnapshotCollectionOutput struct {
Snapshots []ScheduleEntitiesSnapshot
}
Click to show internal directories.
Click to hide internal directories.